NAME

Peta::NN::Backend::PDL - Peta::NN on PDL ndarrays

VERSION

version 0.2610090

SYNOPSIS

my $net = Peta::NN->new(input => 2, layers => [ [dense => 2] ], backend => 'pdl');

DESCRIPTION

Double precision, on the CPU. Results agree with the plain backend to rounding, not to the bit: a matrix product sums in another order. See Peta::NN::Backend for the operations.

METHODS

This class implements the backend interface described in "THE BACKEND INTERFACE" in Peta::NN::Backend and adds nothing to it.

AUTHOR

PetaMem s.r.o. <info@petamem.com>

COPYRIGHT

Copyright (c) 2026 PetaMem s.r.o.

LICENSE

This package is free software, dual-licensed under the Artistic License 2.0 and the BSD 2-Clause License. See the LICENSE file of the distribution.